@@ -298,6 +298,8 @@ soup_auth_ntlm_update_connection (SoupConnectionAuth *auth, SoupMessage *msg,
 		return FALSE;
 
 	if (conn->state > SOUP_NTLM_SENT_REQUEST) {
+		conn->state = SOUP_NTLM_FAILED;
+
 		if (priv->password_state == SOUP_NTLM_PASSWORD_ACCEPTED) {
 			/* We know our password is correct, so a 401
 			 * means "permission denied". Since the conn
@@ -305,21 +307,11 @@ soup_auth_ntlm_update_connection (SoupConnectionAuth *auth, SoupMessage *msg,
 			 * is_ready() for this message, so this will
 			 * cause a "retrying" authenticate signal.
 			 */
-			conn->state = SOUP_NTLM_FAILED;
 			return TRUE;
 		}
 
-#ifdef USE_NTLM_AUTH
-		if (priv->sso_available) {
-			conn->state = SOUP_NTLM_SSO_FAILED;
-			priv->password_state = SOUP_NTLM_PASSWORD_NONE;
-		} else {
-#endif
-			conn->state = SOUP_NTLM_FAILED;
-			priv->password_state = SOUP_NTLM_PASSWORD_REJECTED;
-#ifdef USE_NTLM_AUTH
-		}
-#endif
+		/* Otherwise, we just have a bad password. */
+		priv->password_state = SOUP_NTLM_PASSWORD_REJECTED;
 		return TRUE;
 	}
 
@@ -380,7 +372,7 @@ soup_auth_ntlm_get_protection_space (SoupAuth *auth, SoupURI *source_uri)
 
 	space = g_strdup (source_uri->path);
 
-	/* Strip query and filename component */
+	/* Strip filename component */
 	p = strrchr (space, '/');
 	if (p && p != space && p[1])
 		*p = '\0';
@@ -441,7 +433,7 @@ soup_auth_ntlm_is_connection_ready (SoupConnectionAuth *auth,
 	if (priv->password_state == SOUP_NTLM_PASSWORD_PROVIDED)
 		return TRUE;
 
-	return conn->state != SOUP_NTLM_FAILED;
+	return conn->state != SOUP_NTLM_FAILED && conn->state != SOUP_NTLM_SSO_FAILED;
 }
 
 static void
