@@ -11,7 +11,6 @@
 
 #include "soup-connection.h"
 #include "soup.h"
-#include "soup-marshal.h"
 #include "soup-message-queue.h"
 #include "soup-misc-private.h"
 
@@ -249,7 +248,7 @@ soup_connection_class_init (SoupConnectionClass *connection_class)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (SoupConnectionClass, disconnected),
 			      NULL, NULL,
-			      _soup_marshal_NONE__NONE,
+			      NULL,
 			      G_TYPE_NONE, 0);
 
 	/* properties */
@@ -971,8 +970,5 @@ soup_connection_send_request (SoupConnection          *conn,
 
 	if (item->msg != priv->current_msg)
 		set_current_msg (conn, item->msg);
-	else
-		priv->reusable = FALSE;
-
 	soup_message_send_request (item, completion_cb, user_data);
 }
